*******
How Tos
*******

.. contents:: Contents
   :depth: 4
   :local:

.. include:: user_information/how_tos/agenda.rst
.. include:: user_information/how_tos/device_setup.rst
.. include:: user_information/how_tos/revent.rst
